@@ -5,7 +5,6 @@ import sys
 import math
 from functools import reduce
 from enum import IntEnum, Enum
-from sys import float_info
 from typing import List, Optional, Union
 
 from pydantic import BaseModel, validator, root_validator, conlist
@@ -22,7 +21,7 @@ from optimade.models.utils import (
 )
 from optimade.server.warnings import MissingExpectedField
 
-EXTENDED_CHEMICAL_SYMBOLS = CHEMICAL_SYMBOLS + EXTRA_SYMBOLS
+EXTENDED_CHEMICAL_SYMBOLS = set(CHEMICAL_SYMBOLS + EXTRA_SYMBOLS)
 
 
 __all__ = (
@@ -36,7 +35,8 @@ __all__ = (
 )
 
 
-EPS = float_info.epsilon
+# Use machine epsilon for single point floating precision
+EPS = 2 ** -23
 
 
 Vector3D = conlist(float, min_items=3, max_items=3)
@@ -145,8 +145,10 @@ Note: With regards to "source database", we refer to the immediate source being
 
     @validator("chemical_symbols", each_item=True)
     def validate_chemical_symbols(cls, v):
-        if not (v in EXTENDED_CHEMICAL_SYMBOLS):
-            raise ValueError(f"{v} MUST be in {EXTENDED_CHEMICAL_SYMBOLS}")
+        if v not in EXTENDED_CHEMICAL_SYMBOLS:
+            raise ValueError(
+                f'{v!r} MUST be an element symbol, e.g., "C", "He", or a special symbol from {EXTRA_SYMBOLS}.'
+            )
         return v
 
     @validator("concentration", "mass")
@@ -944,7 +946,7 @@ The properties of the species are found in the property `species`.
 
         if abs(sum(v) - 1) > EPS:
             raise ValueError(
-                f"elements_ratios MUST sum to 1 within floating point accuracy. It sums to: {sum(v)}"
+                f"elements_ratios MUST sum to 1 within (at least single precision) floating point accuracy. It sums to: {sum(v)}"
             )
         return v
 
